Coverage report

File | statements | missing | excluded | coverage
--- | --- | --- | --- | ---
denofo/__init__.py | 1 | 0 | 0 | 100%
denofo/choices.py | 60 | 0 | 0 | 100%
denofo/comparator/__init__.py | 0 | 0 | 0 | 100%
denofo/comparator/comparator_cli.py | 33 | 1 | 0 | 97%
denofo/comparator/comparator_gui.py | 157 | 17 | 0 | 89%
denofo/comparator/compare.py | 69 | 0 | 0 | 100%
denofo/converter/__init__.py | 0 | 0 | 0 | 100%
denofo/converter/convert.py | 108 | 17 | 0 | 84%
denofo/converter/converter_cli.py | 75 | 13 | 0 | 83%
denofo/converter/converter_gui.py | 279 | 79 | 0 | 72%
denofo/models.py | 136 | 4 | 0 | 97%
denofo/questionnaire/__init__.py | 0 | 0 | 0 | 100%
denofo/questionnaire/questionnaire_cli.py | 266 | 36 | 0 | 86%
denofo/questionnaire/questionnaire_gui.py | 384 | 75 | 0 | 80%
denofo/questionnaire/questions.py | 401 | 56 | 0 | 86%
denofo/utils/__init__.py | 0 | 0 | 0 | 100%
denofo/utils/constants.py | 9 | 0 | 0 | 100%
denofo/utils/helpers.py | 197 | 81 | 0 | 59%
denofo/utils/ncbiTaxDBcheck.py | 18 | 0 | 0 | 100%
Total | 2193 | 379 | 0 | 83%

No items found using the specified filter.